@@ -105,7 +105,8 @@ itcl::body FitsImage::constructor {args} {
 	if { ![catch {$fFile getKeyword BZERO}] ||
 	![catch {$fFile getKeyword BSCALE}] } {
 	    set _imgType 4
-	    set _imgForm "% #.10E"
+	    # set _imgForm "% #.10E"
+	    set _imgForm "%g"
 	} else {
 	    if { $_bitpixKey == "8" } {
 		set _imgType 0 
@@ -118,10 +119,12 @@ itcl::body FitsImage::constructor {args} {
 		set _imgForm "%d"
 	    } elseif {$_bitpixKey == "-32"} {
 		set _imgType 3 
-		set _imgForm "% #.5f"
+		# set _imgForm "% #.5f"
+		set _imgForm "%g"
 	    } elseif {$_bitpixKey == "-64"} {
 		set _imgType 4 
-		set _imgForm "% #.10E"
+		# set _imgForm "% #.10E"
+		set _imgForm "%g"
 	    } elseif {$_bitpixKey == "64"} {
 		set _imgType 5 
 	        set _imgForm "%s"
