@@ -267,6 +267,7 @@ namespace eval fvCmds {
    proc export { args } {
        global isWin
        global isMac
+       global g_backupDir
        variable currObj
        variable currHDU
 
@@ -294,9 +295,8 @@ namespace eval fvCmds {
           set extList [split $extension " "]
        }
 
-       file copy -force $fileName $::env(HOME)/.fv/[file tail $fileName]
-       catch { set openedFileName $::env(HOME)/.fv/[file tail $fileName] } err
-
+       file copy -force $fileName $g_backupDir/[file tail $fileName]
+       catch { set openedFileName $g_backupDir/[file tail $fileName] } err
 
        switch $option {
               "hdu" {
@@ -376,8 +376,8 @@ namespace eval fvCmds {
                      set r [file root $r]
                   }
 
-                  file copy -force $fileName $::env(HOME)/.fv/[file tail $fileName]
-                  catch { set openedFileName $::env(HOME)/.fv/[file tail $fileName] } err
+                  file copy -force $fileName $g_backupDir/[file tail $fileName]
+                  catch { set openedFileName $g_backupDir/[file tail $fileName] } err
 
                   catch { set tmpfitsfile [fits open $openedFileName 0] } err
                   catch  { set currentHDU [$tmpfitsfile info chdu] } err
@@ -1472,6 +1472,7 @@ namespace eval fvXPA {
             open       1 1 "Open a FITS file"                            \
             opentool   0 1 "Open other tools, SkyView Catalogs, VizieR"  \
             pow        1 1 "Execute a pow command"                       \
+            plot       1 1 "Execute a plot command"                       \
             preference 0 1 "Change the preference of fv"                 \
             quit       0 1 "Quit fv"                                     \
             save       0 1 "Save file"                                   \
