@@ -238,7 +238,11 @@ proc promptMsg {text_ command_ okText_ cancelText_ {newCmdText ""} } {
              -message $text_ -icon question ]
         }
         if { $choice == "yes"  } {
-          $command_
+          #
+          # Pan Chai 04-10-2018
+          #          - add "eval" to handle iwidget 4.01 not working nicely
+          #            with current Tcl/Tk 
+          eval "$command_"
 	  return
         } elseif {$choice == "cancel"} {
 	    return BREAK
@@ -287,7 +291,11 @@ proc promptMsg {text_ command_ okText_ cancelText_ {newCmdText ""} } {
     #     val: other
 
     if { $fb == 1  } {
-	$command_
+        #
+        # Pan Chai 04-10-2018
+        #          - add "eval" to handle iwidget 4.01 not working nicely
+        #            with current Tcl/Tk 
+	eval "$command_"
 	return
     } elseif {$fb == 0} {
 	return CANCEL
@@ -813,14 +821,25 @@ proc resolveSymLinks { filename_ } {
 
 
 proc loadTclCode { hostPath_ sourceFile_ } {
+   global tcl_platform
    global serverIdx
 #puts loadTclCode
+#puts "hostPath_: $hostPath_"
+#puts "sourceFile_: $sourceFile_"
 
    set returnStr "SUCCESSFUL"
-   package require http
-   set errorFlag [ catch {
-       set urlToken [http::geturl "$hostPath_/$sourceFile_"] 
-   } err ]
+
+   if { $tcl_platform(platform) != "windows" } {
+      set errorFlag [ catch {
+          exec curl -s -k -X GET "$hostPath_/$sourceFile_"
+      } urlToken ]
+   } else {
+      set errorFlag [ catch {
+          exec curl.exe -s -k -X GET "$hostPath_/$sourceFile_"
+      } urlToken ]
+   } 
+
+#puts $urlToken
 
    if { $errorFlag } {
 
@@ -845,15 +864,17 @@ proc loadTclCode { hostPath_ sourceFile_ } {
 
       return FAILED
    } else {
-      set httpCode [http::code $urlToken]
+      # set httpCode [http::code $urlToken]
 
-      if { [string first "404 NOT FOUND" [string toupper $httpCode]] >= 0 } {
-         return MODULE_NOT_FOUND
-      }
+      # if { [string first "404 NOT FOUND" [string toupper $httpCode]] >= 0 } {
+      #    return MODULE_NOT_FOUND
+      # }
 
    }
 
-   set contents [http::data $urlToken]
+   # set contents [http::data $urlToken]
+   set contents $urlToken
+
    if { $sourceFile_ == "tclIndex" } {
       set targetList [split $contents \n]
       set targetLine ""
@@ -864,7 +885,7 @@ proc loadTclCode { hostPath_ sourceFile_ } {
               break
            }
       }
-#puts "targetLine: $targetLine"
+# puts "targetLine: $targetLine"
       if { $targetLine != "" } {
          regsub -all ":" $targetLine "" targetLine 
          set tokenList [split $targetLine "()"]     
@@ -872,10 +893,10 @@ proc loadTclCode { hostPath_ sourceFile_ } {
          set idx [string first "init" $targetModule]
          set returnStr [string range $targetModule 0 [expr $idx - 1]] 
       }
-#puts "returnStr: $returnStr"
+# puts "returnStr: $returnStr"
    }
 
-   http::cleanup $urlToken
+   # http::cleanup $urlToken
    if { $sourceFile_=="tclIndex" } {
       #  Munge standard tclIndex format into WWW format
       regsub -all {source \[file join \$dir} \
@@ -883,7 +904,7 @@ proc loadTclCode { hostPath_ sourceFile_ } {
       regsub -all {\]\]} $tmp {]} contents
    }
    namespace eval :: $contents
-#puts "done loadTclCode"
+# puts "done loadTclCode"
    return $returnStr
 }
 
