@@ -40,7 +40,7 @@ itcl::body fvApp::constructor {args} {
       wm withdraw .
    }
  
-   set g_fvVersion 5.4
+   set g_fvVersion 5.5
    _setupOptions
 
    # Initialize preferences before searching through command-line options
@@ -201,8 +201,8 @@ itcl::body fvApp::_loadLibs { } {
       if ![ info exist env(FV_ISEXEC) ] {
           set env(POW_LIBRARY) "$FITSVIEWER_LIBRARY/../pow"
           set  env(POW_HELPDIR) $env(POW_LIBRARY)
-          load [glob $FITSVIEWER_LIBRARY/../libfitstcl.{s\[ol\]*,dylib}]
-          load [glob $FITSVIEWER_LIBRARY/../libpow.{s\[ol\]*,dylib}]
+          load [glob $FITSVIEWER_LIBRARY/../libfitstcl.{s\[ol\]*,dylib,dll}]
+          load [glob $FITSVIEWER_LIBRARY/../libpow.{s\[ol\]*,dylib,dll}]
       } else {
 	  if ![info exist env(FV_HELPDIR)] {
 	     set fullname [info nameofexecutable]
