@@ -38,6 +38,7 @@ itcl::class fvPreferences {
       method _toggleCheckedSizeState { dim }
       method _deleteCheckedSize { {op "delete"} }
       method _addNewSize {}
+      method _setupFont {}
 
       variable note
       variable _FVRC
@@ -99,7 +100,7 @@ itcl::body fvPreferences::constructor { args } {
       variable winManagement        Keep
       variable graphDispSize        [list 300 300]
       variable FontSize             12
-      variable webModulesURLsHead   "http://heasarc.gsfc.nasa.gov/hera/"
+      variable webModulesURLsHead   "https://hera.gsfc.nasa.gov/hera/"
       variable BrowserSetting       "None Defined"
       variable GraphDefaultSizeList [list 100x100 120x120 160x160 200x200 256x256 300x300 400x400 500x500 600x600 700x700 300x400 400x300] 
    }
@@ -130,7 +131,7 @@ itcl::body fvPreferences::constructor { args } {
    }
 
    if [info exists env(HERA_SERVER) ] {
-      set fvPref::webModulesURLsHead "http://$env(HERA_SERVER)/hera/"
+      set fvPref::webModulesURLsHead "https://$env(HERA_SERVER)/hera/"
    } 
       
    #  Read in the preferences file
@@ -419,7 +420,13 @@ itcl::body fvPreferences::save {} {
    set _previousDirectory ""
    catch { wm deiconify .browseDirectorySetup }
    catch { wm withdraw .browseDirectorySetup }
-   fvApp::_setupFont
+   
+   # 
+   # Pan Chai 09-20-2017
+   #
+   # change _setupFont here to handle font setup, calling fvApp::_setupFont is not working
+   # in the new Tcl/Tk 8.6+
+   _setupFont
 
 # puts "Options saved in $_FVRC"
 }
@@ -1230,3 +1237,40 @@ itcl::body fvPreferences::_correctPath { path } {
      return $newStr
 }
 
+itcl::body fvPreferences::_setupFont { } {
+    # 
+    # Pan Chai 09-20-2017
+    #
+    # add _setupFont here to handle font setup.
+    #
+
+    global g_charPix
+    global isWin isMac
+
+    catch { font delete g_titleFont g_notebookTitleFont g_entryFont }
+    catch { destroy .dummyFnt1 }
+    catch { destroy .dummyFnt2 }
+    catch { destroy .dummyFnt3 }
+    catch { destroy .dummyFnt4 }
+
+    if { $isWin } {
+       font create g_titleFont -family Arial             -size -$fvPref::FontSize
+       font create g_notebookTitleFont -family Arial     -size -[expr $fvPref::FontSize + 2]
+    } elseif { $isMac } {
+       font create g_titleFont -family system    -size -$fvPref::FontSize
+       font create g_notebookTitleFont -family system -size -[expr $fvPref::FontSize + 2]
+    } else {
+       font create g_titleFont -family Helvetica -size -$fvPref::FontSize -weight bold
+       font create g_notebookTitleFont -family Helvetica -size -[expr $fvPref::FontSize + 2] -weight bold
+    }
+
+    font create g_entryFont -family Courier -size -$fvPref::FontSize
+    set g_charPix      [font measure g_entryFont m]
+
+    # These lines guarantee that the default fonts are always loaded.
+    entry .dummyFnt1
+    entry .dummyFnt2 -font g_entryFont
+    entry .dummyFnt3 -font g_titleFont
+    entry .dummyFnt4 -font g_notebookTitleFont
+    option add *FitsFileselectionbox.font g_titleFont
+}
