@@ -2,7 +2,6 @@
 #include <string.h>
 #include <stdio.h>
 #include "pow.h"
-#include "wcslib/wcstrig.h"
 
 #define DEG2RAD 1.745329252e-2
 
@@ -125,10 +124,10 @@ int PowParseWCS( Tcl_Interp *interp, WCSdata *WCS,
 
       if( argc>8 ) Tcl_GetBooleanFromObj(interp,argv[8],&swap);
 
-      cdFrwd[0][0] =  xinc * cosd( rot * DEG2RAD );
-      cdFrwd[0][1] = -yinc * sind( rot * DEG2RAD );
-      cdFrwd[1][0] =  xinc * sind( rot * DEG2RAD );
-      cdFrwd[1][1] =  yinc * cosd( rot * DEG2RAD );
+      cdFrwd[0][0] =  xinc * cos( rot * DEG2RAD );
+      cdFrwd[0][1] = -yinc * sin( rot * DEG2RAD );
+      cdFrwd[1][0] =  xinc * sin( rot * DEG2RAD );
+      cdFrwd[1][1] =  yinc * cos( rot * DEG2RAD );
       nDims = 2;
 
    } else {
@@ -670,8 +669,8 @@ int pow_worldpos(double xpix, double ypix,
    l    =  dx  * cond2r;
    m    =  dy  * cond2r;
    sins = l*l + m*m;
-   cos0 = cosd(dec0);
-   sin0 = sind(dec0);
+   cos0 = cos(dec0);
+   sin0 = sin(dec0);
 
    /* process by case  */
    switch (itype) {
@@ -680,48 +679,48 @@ int pow_worldpos(double xpix, double ypix,
       coss = sqrt (1.0 - sins);
       dt = sin0 * coss + cos0 * m;
       if ((dt>1.0) || (dt<-1.0)) return(501);
-      dect = asind(dt);
+      dect = asin(dt);
       rat = cos0 * coss - sin0 * m;
       if ((rat==0.0) && (l==0.0)) return(501);
-      rat = atan2d(l, rat) + ra0;
+      rat = atan2(l, rat) + ra0;
       break;
     case 1:   /* -TAN tan */
-      x = cos0*cosd(ra0) - l*sind(ra0) - m*cosd(ra0)*sin0;
-      y = cos0*sind(ra0) + l*cosd(ra0) - m*sind(ra0)*sin0;
+      x = cos0*cos(ra0) - l*sin(ra0) - m*cos(ra0)*sin0;
+      y = cos0*sin(ra0) + l*cos(ra0) - m*sin(ra0)*sin0;
       z = sin0                       + m*         cos0;
-      rat  = atan2d( y, x );
-      dect = atand( z / sqrt(x*x+y*y) );
+      rat  = atan2( y, x );
+      dect = atan( z / sqrt(x*x+y*y) );
       break;
     case 2:   /* -ARC Arc*/
       if (sins>=pi*pi) return(501);
       sins = sqrt(sins);
-      coss = cosd(sins);
-      if (sins!=0.0) sins = sind(sins) / sins;
+      coss = cos(sins);
+      if (sins!=0.0) sins = sin(sins) / sins;
       else
 	sins = 1.0;
       dt = m * cos0 * sins + sin0 * coss;
       if ((dt>1.0) || (dt<-1.0)) return(501);
-      dect = asind(dt);
+      dect = asin(dt);
       da = coss - dt * sin0;
       dt = l * sins * cos0;
       if ((da==0.0) && (dt==0.0)) return(501);
-      rat = ra0 + atan2d(dt, da);
+      rat = ra0 + atan2(dt, da);
       break;
     case 3:   /* -NCP North celestial pole*/
       dect = cos0 - m * sin0;
       if (dect==0.0) return(501);
-      rat = ra0 + atan2d(l, dect);
-      dt = cosd(rat-ra0);
+      rat = ra0 + atan2(l, dect);
+      dt = cos(rat-ra0);
       if (dt==0.0) return(501);
       dect = dect / dt;
       if ((dect>1.0) || (dect<-1.0)) return(501);
-      dect = acosd(dect);
+      dect = acos(dect);
       if (dec0<0.0) dect = -dect;
       break;
     case 4:   /* -GLS global sinusoid */
       dect = dec0 + m;
       if (fabs(dect)>pi/2.0) return(501);
-      coss = cosd(dect);
+      coss = cos(dect);
       if (fabs(l)>pi*coss) return(501);
       rat = ra0;
       if (coss>deps) rat = rat + l / coss;
@@ -733,18 +732,18 @@ int pow_worldpos(double xpix, double ypix,
       if (dt==0.0) dt = 1.0;
       dy = (refVal[1]*0.5 + 45.0) * cond2r;
       dx = dy + dt / 2.0 * cond2r;
-      dy = log (tand(dy));
-      dx = log (tand(dx));
+      dy = log (tan(dy));
+      dx = log (tan(dx));
       geo2 = dt * cond2r / (dx - dy);
       geo3 = geo2 * dy;
-      geo1 = cosd(refVal[1]*cond2r);
+      geo1 = cos(refVal[1]*cond2r);
       if (geo1<=0.0) geo1 = 1.0;
       rat = l / geo1 + ra0;
       if (fabs(rat - ra0) > pi+pi) return(501);
       dt = 0.0;
       if (geo2!=0.0) dt = (m + geo3) / geo2;
       dt = exp (dt);
-      dect = 2.0 * atand(dt) - pi / 2.0;
+      dect = 2.0 * atan(dt) - pi / 2.0;
       break;
     case 6:   /* -AIT Aitoff */
       /*  dt = yinc * cosr + xinc * sinr;  */
@@ -753,8 +752,8 @@ int pow_worldpos(double xpix, double ypix,
       if (dt==0.0) dt = 1.0;
       dt = dt * cond2r;
       dy = dec0;
-      dx = sind(dy+dt)/sqrt((1.0+cosd(dy+dt))/2.0) -
-	  sind(dy)/sqrt((1.0+cosd(dy))/2.0);
+      dx = sin(dy+dt)/sqrt((1.0+cos(dy+dt))/2.0) -
+	  sin(dy)/sqrt((1.0+cos(dy))/2.0);
       if (dx==0.0) dx = 1.0;
       geo2 = dt / dx;
       /* Calculate the right ascension change for a (1,1) offset from refpix */
@@ -762,10 +761,10 @@ int pow_worldpos(double xpix, double ypix,
       dt = matrix[0][0] + matrix[0][1];
       if (dt==0.0) dt = 1.0;
       dt = dt * cond2r;
-      dx = 2.0 * cosd(dy) * sind(dt/2.0);
+      dx = 2.0 * cos(dy) * sin(dt/2.0);
       if (dx==0.0) dx = 1.0;
-      geo1 = dt * sqrt((1.0+cosd(dy)*cosd(dt/2.0))/2.0) / dx;
-      geo3 = geo2 * sind(dy) / sqrt((1.0+cosd(dy))/2.0);
+      geo1 = dt * sqrt((1.0+cos(dy)*cos(dt/2.0))/2.0) / dx;
+      geo3 = geo2 * sin(dy) / sqrt((1.0+cos(dy))/2.0);
       rat = ra0;
       dect = dec0;
       if ((l==0.0) && (m==0.0)) break;
@@ -774,11 +773,11 @@ int pow_worldpos(double xpix, double ypix,
       dz = 0.5 * sqrt (dz);
       dd = (m+geo3) * dz / geo2;
       if (fabs(dd)>1.0) return(501);
-      dd = asind(dd);
-      if (fabs(cosd(dd))<deps) return(501);
-      da = l * dz / (2.0 * geo1 * cosd(dd));
+      dd = asin(dd);
+      if (fabs(cos(dd))<deps) return(501);
+      da = l * dz / (2.0 * geo1 * cos(dd));
       if (fabs(da)>1.0) return(501);
-      da = asind(da);
+      da = asin(da);
       rat = ra0 + 2.0 * da;
       dect = dd;
       break;
@@ -787,15 +786,15 @@ int pow_worldpos(double xpix, double ypix,
       if (fabs(dz)>1.0) return(501);
       dect = dz * sin0 + m * cos0 * (1.0+dz) / 2.0;
       if (fabs(dect)>1.0) return(501);
-      dect = asind(dect);
-      rat = cosd(dect);
+      dect = asin(dect);
+      rat = cos(dect);
       if (fabs(rat)<deps) return(501);
       rat = l * (1.0+dz) / (2.0 * rat);
       if (fabs(rat)>1.0) return(501);
-      rat = asind(rat);
-      mg = 1.0 + sind(dect) * sin0 + cosd(dect) * cos0 * cosd(rat);
+      rat = asin(rat);
+      mg = 1.0 + sin(dect) * sin0 + cos(dect) * cos0 * cos(rat);
       if (fabs(mg)<deps) return(501);
-      mg = 2.0 * (sind(dect) * cos0 - cosd(dect) * sin0 * cosd(rat)) / mg;
+      mg = 2.0 * (sin(dect) * cos0 - cos(dect) * sin0 * cos(rat)) / mg;
       if (fabs(mg-m)>deps) rat = pi - rat;
       rat = ra0 + rat;
       break;
@@ -898,53 +897,53 @@ int pow_xypx(double xpos, double ypos,
    else if( dRA <= -pi ) dRA += pi + pi;
 
    /* compute direction cosine */
-   coss = cosd(dec);
-   sins = sind(dec);
-   cos0 = cosd(dec0);
-   sin0 = sind(dec0);
-   l = sind(dRA) * coss;
-   sint = sins * sin0 + coss * cos0 * cosd(dRA);
+   coss = cos(dec);
+   sins = sin(dec);
+   cos0 = cos(dec0);
+   sin0 = sin(dec0);
+   l = sin(dRA) * coss;
+   sint = sins * sin0 + coss * cos0 * cos(dRA);
 
    /* process by case  */
    switch (itype) {
     case 0:   /* -SIN sin*/ 
          if (sint<0.0) return(501);
-         m = sins * cosd(dec0) - coss * sind(dec0) * cosd(dRA);
+         m = sins * cos(dec0) - coss * sin(dec0) * cos(dRA);
       break;
     case 1:   /* -TAN tan */
          if (sint<=0.0) return(501);
          if( cos0<0.001 ) {
             /* Do a first order expansion around pole */
-            m = (coss * cosd(dRA)) / (sins * sin0);
+            m = (coss * cos(dRA)) / (sins * sin0);
             m = (-m + cos0 * (1.0 + m*m)) / sin0;
          } else {
             m = ( sins/sint - sin0 ) / cos0;
          }
-	 if( fabs(sind(ra0)) < 0.3 ) {
-	    l  = coss*sind(ra)/sint - cos0*sind(ra0) + m*sind(ra0)*sin0;
-	    l /= cosd(ra0);
+	 if( fabs(sin(ra0)) < 0.3 ) {
+	    l  = coss*sin(ra)/sint - cos0*sin(ra0) + m*sin(ra0)*sin0;
+	    l /= cos(ra0);
 	 } else {
-	    l  = coss*cosd(ra)/sint - cos0*cosd(ra0) + m*cosd(ra0)*sin0;
-	    l /= -sind(ra0);
+	    l  = coss*cos(ra)/sint - cos0*cos(ra0) + m*cos(ra0)*sin0;
+	    l /= -sin(ra0);
 	 }
       break;
     case 2:   /* -ARC Arc*/
-         m = sins * sind(dec0) + coss * cosd(dec0) * cosd(dRA);
+         m = sins * sin(dec0) + coss * cos(dec0) * cos(dRA);
          if (m<-1.0) m = -1.0;
          if (m>1.0) m = 1.0;
-         m = acosd(m);
+         m = acos(m);
          if (m!=0) 
-            m = m / sind(m);
+            m = m / sin(m);
          else
             m = 1.0;
          l = l * m;
-         m = (sins * cosd(dec0) - coss * sind(dec0) * cosd(dRA)) * m;
+         m = (sins * cos(dec0) - coss * sin(dec0) * cos(dRA)) * m;
       break;
     case 3:   /* -NCP North celestial pole*/
          if (dec0==0.0) 
 	     return(501);  /* can't stand the equator */
          else
-	   m = (cosd(dec0) - coss * cosd(dRA)) / sind(dec0);
+	   m = (cos(dec0) - coss * cos(dRA)) / sin(dec0);
       break;
     case 4:   /* -GLS global sinusoid */
          if (fabs(dec) >pi*0.5) return(501);
@@ -959,13 +958,13 @@ int pow_xypx(double xpos, double ypos,
          if (dt==0.0) dt = 1.0;
          dy = (dec0 + 90.0 * cond2r) * 0.5;
          dx = dy + (dt * 0.5) * cond2r;
-         dy = log (tand(dy));
-         dx = log (tand(dx));
+         dy = log (tan(dy));
+         dx = log (tan(dx));
          geo2 = dt * cond2r / (dx - dy);
          geo3 = geo2 * dy;
-         l  = dRA * cosd(dec0);
+         l  = dRA * cos(dec0);
          dt = dec * 0.5 + pi * 0.25;
-         dt = tand(dt);
+         dt = tan(dt);
          if (dt<deps) return(502);
          m = geo2 * log (dt) - geo3;
          break;
@@ -978,8 +977,8 @@ int pow_xypx(double xpos, double ypos,
          if (dt==0.0) dt = 1.0;
          dt = dt * cond2r;
          dy = dec0;
-         dx = sind(dy+dt)/sqrt((1.0+cosd(dy+dt))/2.0) -
-             sind(dy)/sqrt((1.0+cosd(dy))/2.0);
+         dx = sin(dy+dt)/sqrt((1.0+cos(dy+dt))/2.0) -
+             sin(dy)/sqrt((1.0+cos(dy))/2.0);
          if (dx==0.0) dx = 1.0;
          geo2 = dt / dx;
          /* Calculate the RA change for a (1,1) offset from refpix */
@@ -987,22 +986,22 @@ int pow_xypx(double xpos, double ypos,
          dt = matrixF[0][0] + matrixF[0][1];
          if (dt==0.0) dt = 1.0;
          dt = dt * cond2r;
-         dx = 2.0 * cosd(dy) * sind(dt/2.0);
+         dx = 2.0 * cos(dy) * sin(dt/2.0);
          if (dx==0.0) dx = 1.0;
-         geo1 = dt * sqrt((1.0+cosd(dy)*cosd(dt/2.0))/2.0) / dx;
-         geo3 = geo2 * sind(dy) / sqrt((1.0+cosd(dy))/2.0);
-         dt = sqrt ((1.0 + cosd(dec) * cosd(da))/2.0);
+         geo1 = dt * sqrt((1.0+cos(dy)*cos(dt/2.0))/2.0) / dx;
+         geo3 = geo2 * sin(dy) / sqrt((1.0+cos(dy))/2.0);
+         dt = sqrt ((1.0 + cos(dec) * cos(da))/2.0);
          if (fabs(dt)<deps) return(503);
-         l = 2.0 * geo1 * cosd(dec) * sind(da) / dt;
-         m = geo2 * sind(dec) / dt - geo3;
+         l = 2.0 * geo1 * cos(dec) * sin(da) / dt;
+         m = geo2 * sin(dec) / dt - geo3;
       break;
     case 7:   /* -STG Sterographic*/
          if (fabs(dec)>0.5*pi) return(501);
-         dd = 1.0 + sins * sind(dec0) + coss * cosd(dec0) * cosd(dRA);
+         dd = 1.0 + sins * sin(dec0) + coss * cos(dec0) * cos(dRA);
          if (fabs(dd)<deps) return(501);
          dd = 2.0 / dd;
          l = l * dd;
-         m = dd * (sins * cosd(dec0) - coss * sind(dec0) * cosd(dRA));
+         m = dd * (sins * cos(dec0) - coss * sin(dec0) * cos(dRA));
       break;
    case 8:    /* -CAR Cartesian  */
       /* l = ra - ra0; */
